/*
Servotester with Arduino Mini Pro

Modified from some internet file :-)

Servo output = pin 2

Run button = pin 5
Minus button = pin 4
Plus button = pin 3
buttons between GND and pin, pull-up resistors 10k to +5V

RUN LED = pin 10
MINUS LED = pin 11
PLUS LED = pin 12

Display Banggood SSD1306 0.96" OLED I2C 
SDA = Pin A4
SCL = PIN A5


Status indication in binary code:
Mode    MINUS LED   PLUS LED   
0       0           0
1       0           1
2       1           0
3       1           1

Mode 0
Manual servo control with step 1% from -100% to +100%

Mode 1
Servo cycling contiously from -100% to +100% and back with step 1% to 10%

Mode 2
Servo cycling from -100% to +100% contiously and jump to -100%

Mode 3
Servo jumps -100% to 0% to +100% and back with variable jump delay 0.4 to 9.9s.

7. February 2017
ddano007@rcmodelytt.sk

7.III.2018
added SETUP with storage to EEPROM

*/

//#include <Servo.h>
#include "U8glib.h"  //https://code.google.com/p/u8glib/
#include <OneWire.h>
#include <EEPROM.h>


U8GLIB_SSD1306_128X64_2X u8g(U8G_I2C_OPT_NONE);     //Banggood SSD1306 0.96" OLED I2C     http://www.banggood.com/0_96-Inch-White-IIC-I2C-OLED-Display-Module-12864-LED-For-Arduino-p-932606.html
                                                       //SDA = Pin A4 ; SCL = PIN A5

const byte LED = 13;
volatile int PulseWidth = 1500;
volatile int Smer = 0;
int citac = 0;

volatile int val= 0;    
volatile int outservo = 100;  
volatile int smer = 2;  // direction up  or down
volatile int ServoMode = 0       ; 
volatile int Zmena = 0       ; 
volatile int Step = 1       ;  
volatile int RunStatus = 0;     // 0 = stop, 1 = run

int RunLed = 10;
int MinusLed = 11; 
int PlusLed = 12;
int RunButton = 5; 
int MinusButton = 4; 
int PlusButton = 3; 

int RunButtonStatus = 1;  
int RunButtonStatusOld = 1;  
int MinusButtonStatus = 1;  
int MinusButtonStatusOld = 1;   
int PlusButtonStatus = 1; 
int PlusButtonStatusOld = 1;
int StepDefault = 1       ; 
int ValStep = 1       ;  
int MinStep = 1       ;   
int MaxStep = 10       ;  

int temp;
int eepromok;
int StoreToEepromOn = 1;
volatile int ServoPin = 2;
volatile int MinRange = 1000      ; //  in usec
int MinRangeLimit = 500  ; //  in usec
volatile int MaxRange = 2000      ; //  in usec
int MaxRangeLimit = 2500 ;  //  in usec
volatile int MidRange = 1500      ; //  in usec
int SetupLevel = 0      ; //  0 = off, 1=main menu
int SetupLevelItem = 0      ; //  0 = Exit, 1=Timer, ...
int SetupLevelTwoItem = 0      ; //  0 = Exit, 1=Timer, ...
int SetupLevelThreeItem = 0      ; //  0 = Exit, 1=Timer, ...


int TimerOn = 1      ; //  0 = off, 1=on
int ServoTimer = 0 ; // Timer time in ms, default 5 minutes
unsigned long ServoCounter = 0 ; // Timer time in ms, default 5 minutes
unsigned long Second = 920 ; // Timer time in ms, default 5 minutes
int ServoTimerDisplay = 0  ;
int TimerTime = 330  ; // Timer time in s, default 5:30 minutes
int TimerTimeMax = 3600 ; // Maximum Timer time 60 minutes
int TimerTimeMin = 10 ; // Minimum Timer time 10 sec


float SSSval = 1.2      ; //  
volatile unsigned long ServoModeTwoTimer = 0 ; // casovac
volatile unsigned long SSSCycleDefault = 500 ; // SSS perioda 500ms
volatile unsigned long SSSCycleStep = 200 ; // Krok SSS periody 200ms
volatile unsigned long SSSCycleMin = 300 ; // Minimalna SSS perioda 300ms
volatile unsigned long SSSCycleMax = 9900 ; // Maxmalna SSS perioda 9.9s
volatile unsigned long SSSCycle ; // SSS perioda
volatile unsigned long AktualTime = millis();
unsigned long ClickTime  ;
unsigned long ClickTime2  ;
unsigned long FirstClickDefault = 600  ;
unsigned long SecondClickDefault = 2000  ;
unsigned long NextClickDefault = 250  ;
unsigned long NextClickDefault2 = 0  ;
unsigned long KeyboardTime  ;
unsigned long KeyboardTimeDefault = 60  ;// 60ms snimanie klavesnice


  void u8g_prepare(void)                //priprava displeja
  {
  //u8g.setFont(u8g_font_6x10);
  //u8g.setFont(u8g_font_fub42n);
  //u8g.setFontRefHeightExtendedText();
  //u8g.setDefaultForegroundColor();
  //u8g.setFontPosTop();
  }



void setup() {

  // set up Timer 2
  TCCR2A = (1 << WGM21); // režim 2, CTC
  TCCR2B = bit (CS22)| bit (CS21);
  OCR2A =  125;       //  1ms interrupt
  TIMSK2 = bit (OCIE2A);             // interrupt on Compare A Match

  
  temp = eepromtest ();
  if ( eepromok == 0)
    temp = eeprominit ();

  MinRange = EEPROM.read(12);
  MinRange = 256*MinRange + EEPROM.read(11);
  MaxRange = EEPROM.read(14);
  MaxRange = 256*MaxRange + EEPROM.read(13);
  MidRange = EEPROM.read(16);
  MidRange = 256*MidRange + EEPROM.read(15);
  TimerTime = EEPROM.read(18);
  TimerTime = 256*TimerTime + EEPROM.read(17);
  TimerOn = EEPROM.read(20);
  TimerOn = 256*TimerOn + EEPROM.read(19);
  StoreToEepromOn = EEPROM.read(22);
  StoreToEepromOn = 256*StoreToEepromOn + EEPROM.read(21);
  
  pinMode(ServoPin, OUTPUT);
  pinMode(LED, OUTPUT);
//  pulz(MidRange, 2);
  pinMode(RunLed, OUTPUT);  // declare LED as output
  pinMode(MinusLed, OUTPUT);  // declare LED as output
  pinMode(PlusLed, OUTPUT);  // declare LED as output
  pinMode(RunButton, INPUT);    // declare pushbutton as input
  pinMode(MinusButton, INPUT);    // declare pushbutton as input
  pinMode(PlusButton, INPUT);    // declare pushbutton as input

    digitalWrite(RunLed, HIGH);  // turn LED OFF
    digitalWrite(MinusLed, HIGH);  // turn LED OFF
    digitalWrite(PlusLed, HIGH);  // turn LED OFF

  u8g.setContrast(0x30);
  u8g_prepare(); 


  u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);
    u8g.drawStr( 0, 18, "Servotester");
    u8g.drawStr( 0, 38, "on Arduino");
    u8g.drawStr( 0, 58, " ddano007");
    } while( u8g.nextPage() );

   delay (3000);

  temp = PrintParameters ();
  temp = PrintAddParam ();
 
  Zmena++;
  KeyboardTime = millis() + KeyboardTimeDefault  ;

  ServoTimer = TimerTime;



}

void loop() {


  AktualTime = millis();

  if ( RunStatus == 1 & ServoMode != 4 & TimerOn ==1 & ServoCounter <= AktualTime )
      {
        ServoCounter = ( ServoCounter + Second );
        ServoTimer--;
        if (ServoTimer <= 0)
          {
            RunStatus = 0;
            ServoTimer = 0;
          }

      Zmena = 3;

      }


  if ( KeyboardTime <= AktualTime )
  {

    KeyboardTime = AktualTime + KeyboardTimeDefault  ;

//********************************************************************************************
//Tlacidlo - RUN - button
//********************************************************************************************

    RunButtonStatus = digitalRead(RunButton);  // read input value

    if (RunButtonStatus == LOW & RunButtonStatusOld == HIGH & ServoMode != 4)
      {
      RunStatus++;
      Zmena = 1;

      ServoTimer = TimerTime;

      if (RunStatus == 2 )
        RunStatus = 0;

      if ( RunStatus == 1 & TimerOn == 1)
        {
          ServoCounter = ( AktualTime + Second) ;
        }
      }

    if (RunButtonStatus == LOW & RunButtonStatusOld == HIGH & ServoMode == 4 )
    {
    if (SetupLevel == 0)
      {
      Zmena++;
      RunStatus = 1;
      SetupLevel++;
      if (SetupLevel >= 1)
        SetupLevel = 1;
      }

    if (SetupLevel == 1 & SetupLevelItem ==0 & Zmena == 0)  //EXIT
      {
      Zmena++;
      RunStatus = 0;
      SetupLevel = 0;
      }

    if (SetupLevel == 1 & SetupLevelItem >0  & Zmena == 0)  // Timer Time ... Save Param. setup
      {
      Zmena++;
      SetupLevel = 2;
      }

    if (SetupLevelItem == 1  & Zmena == 0)  //Timer time
      {
      Zmena++;

      switch ( SetupLevel ){
      case 2:
        if ( SetupLevelTwoItem == 0)
          {
          SetupLevel = 3;  
          SetupLevelThreeItem = 0; 
          }

        if ( SetupLevelTwoItem == 1)
          {
          SetupLevel = 1;  
          SetupLevelTwoItem = 0;
          temp = CancelInfo ();
          }
        break;

      case 3:
        if ( SetupLevelThreeItem == 0 )
        {
        ServoTimer = TimerTime;
        SetupLevel = 1;  
        SetupLevelTwoItem = 0;
        SetupLevelThreeItem = 0;
        temp = TimerTimeInfo ();
        if ( StoreToEepromOn == 1 )
          {
            temp = StoreParameters();
            temp = StoreInfo();
           }
        
        }
        break;
      }
      }


    if (SetupLevel == 2 & SetupLevelItem == 2  & Zmena == 0)  //Timer ON/OFF
      {
      Zmena++;
      SetupLevel = 1;

      if ( SetupLevelTwoItem == 0 )
        {
        TimerOn = 1;
        temp = TimerOnInfo ();
        }

      if ( SetupLevelTwoItem == 1 )
        {
        TimerOn = 0;
        temp = TimerOffInfo ();
        }
      if ( SetupLevelTwoItem == 2 )
        {
        temp = CancelInfo ();
        }

      SetupLevelTwoItem = 0;

      }

    if (SetupLevel == 2 & SetupLevelItem == 3  & Zmena == 0)  //Pulse par.1
      {
      Zmena++;
      SetupLevel = 1;

      if ( SetupLevelTwoItem == 0 )
        {
          MinRange = 1000      ;
          MidRange = 1500      ;
          MaxRange = 2000      ;
          temp = PrintParameters ();
          if ( StoreToEepromOn == 1 )
            {
            temp = StoreParameters();
            temp = StoreInfo();
            }
        }
      if ( SetupLevelTwoItem == 1 )
        {
        temp = CancelInfo ();
        }

      SetupLevelTwoItem = 0;
      
      }


    if (SetupLevel == 2 & SetupLevelItem == 4  & Zmena == 0)  //Pulse par.2
      {
      Zmena++;
      SetupLevel = 1;

      if ( SetupLevelTwoItem == 0 )
        {
        MinRange = 900      ;
        MidRange = 1500      ;
        MaxRange = 2100      ;
        temp = PrintParameters ();
          if ( StoreToEepromOn == 1 )
           {
           temp = StoreParameters();
           temp = StoreInfo();
           }
        }

      if ( SetupLevelTwoItem == 1 )
        {
        temp = CancelInfo ();
        }

      SetupLevelTwoItem = 0;
      
      }


    if (SetupLevel == 2 & SetupLevelItem == 5  & Zmena == 0)  //Pulse par.3
      {
      Zmena++;
      SetupLevel = 1;

      if ( SetupLevelTwoItem == 0 )
        {
          MinRange = 1200      ;
          MidRange = 1500      ;
          MaxRange = 1800      ;
          temp = PrintParameters ();
          if ( StoreToEepromOn == 1 )
            {
            temp = StoreParameters();
            temp = StoreInfo();
            }
        }

      if ( SetupLevelTwoItem == 1 )
        {
        temp = CancelInfo ();
        }

      SetupLevelTwoItem = 0;
      
      }

    if (SetupLevelItem == 6  & Zmena == 0)  //User Pulse Min
      {

      Zmena++;
      switch ( SetupLevel ){
      case 2:
        if ( SetupLevelTwoItem == 0)
          {
          SetupLevel = 3;  
          SetupLevelThreeItem = 0; 
          }

        if ( SetupLevelTwoItem == 1)
          {
          SetupLevel = 1;  
          SetupLevelTwoItem = 0;
          temp = CancelInfo ();
          }
        break;

      case 3:
        if ( SetupLevelThreeItem == 0 )
        {
        SetupLevel = 1;  
        SetupLevelTwoItem = 0;
        SetupLevelThreeItem = 0;
        temp = UserMinInfo ();
        if ( StoreToEepromOn == 1 )
          {
            temp = StoreParameters();
            temp = StoreInfo();
           }
        
        }
        break;
      }
      }

    if (SetupLevelItem == 7  & Zmena == 0)  //User Pulse Mid
      {
      Zmena++;

      switch ( SetupLevel ){
      case 2:
        if ( SetupLevelTwoItem == 0)
          {
          SetupLevel = 3;  
          SetupLevelThreeItem = 0; 
          }

        if ( SetupLevelTwoItem == 1)
          {
          SetupLevel = 1;  
          SetupLevelTwoItem = 0;
          temp = CancelInfo ();
          }
        break;

      case 3:
        if ( SetupLevelThreeItem == 0 )
        {
        SetupLevel = 1;  
        SetupLevelTwoItem = 0;
        SetupLevelThreeItem = 0;
        temp = UserMidInfo ();
        if ( StoreToEepromOn == 1 )
          {
            temp = StoreParameters();
            temp = StoreInfo();
           }
        
        }
        break;
      }
      }

    if (SetupLevelItem == 8  & Zmena == 0)  //User Pulse Mid
      {

      Zmena++;
      switch ( SetupLevel ){
      case 2:
        if ( SetupLevelTwoItem == 0)
          {
          SetupLevel = 3;  
          SetupLevelThreeItem = 0; 
          }

        if ( SetupLevelTwoItem == 1)
          {
          SetupLevel = 1;  
          SetupLevelTwoItem = 0;
          temp = CancelInfo ();
          }
        break;

      case 3:
        if ( SetupLevelThreeItem == 0 )
        {
        SetupLevel = 1;  
        SetupLevelTwoItem = 0;
        SetupLevelThreeItem = 0;
        temp = UserMaxInfo ();
        if ( StoreToEepromOn == 1 )
          {
            temp = StoreParameters();
            temp = StoreInfo();
           }
        
        }
        break;
      }
      }

    if (SetupLevel == 2 & SetupLevelItem == 9  & Zmena == 0)  //Store param.
      {
      Zmena++;
      SetupLevel = 1;

        if ( SetupLevelTwoItem == 0 )
          {
          StoreToEepromOn = 1;
          temp = StoreToEepromOnInfo ();
          if ( StoreToEepromOn == 1 )
          {
            temp = StoreParameters();
            temp = StoreInfo();
           }
        }

        if ( SetupLevelTwoItem == 1 )
          {
          StoreToEepromOn = 0;
          temp = StoreToEepromOffInfo ();
          if ( StoreToEepromOn == 1 )
          {
            temp = StoreParameters();
            temp = StoreInfo();
           }
          }

        if ( SetupLevelTwoItem == 2 )
          {
          StoreToEepromOn = 0;
          temp = CancelInfo ();
          }

      SetupLevelTwoItem = 0;

      }

      Zmena++;
      ClickTime = AktualTime + FirstClickDefault ;
      ClickTime2 = AktualTime + SecondClickDefault ;

     }          
     RunButtonStatusOld = RunButtonStatus;

//********************************************************************************************
//Tlacidlo - MINUS - button
//********************************************************************************************

    MinusButtonStatus = digitalRead(MinusButton);  // read input value

    if (MinusButtonStatus == LOW & MinusButtonStatusOld == HIGH & RunStatus == 0 )
      {
      ServoMode--;
      Zmena++;
      }

    if (MinusButtonStatus == LOW & MinusButtonStatusOld == HIGH & RunStatus == 1)
    {
    if (ServoMode == 0)
      {
      val--;
      if (val <= -100)
        val = -100;
      }

    if (ServoMode == 1)
      {
      Step = Step - ValStep;
      if (Step <= MinStep)
        Step = MinStep;
      }

    if (ServoMode == 2)
      {
      Step = Step - ValStep;
      if (Step <= MinStep)
        Step = MinStep;
      }


    if (ServoMode == 3)
      {
      SSSCycleDefault = SSSCycleDefault - SSSCycleStep;
      if (SSSCycleDefault <= SSSCycleMin)
        SSSCycleDefault = SSSCycleMin;
      }

    if (ServoMode == 4)
    {
    if (SetupLevel == 1)
      {
      SetupLevelItem--;
      if (SetupLevelItem < 0)
        SetupLevelItem = 9;
      }

    if (SetupLevel == 2 & ( SetupLevelItem == 1 || ( SetupLevelItem >= 3 & SetupLevelItem <= 8 )))
      {
      SetupLevelTwoItem--;
      if (SetupLevelTwoItem < 0)
        SetupLevelTwoItem = 1;
      }

    if (SetupLevel == 2 & ( SetupLevelItem == 2 || SetupLevelItem == 9 )  )
      {
      SetupLevelTwoItem--;
      if (SetupLevelTwoItem < 0)
        SetupLevelTwoItem = 2;
      }


    if (SetupLevel == 3)
      {


      switch (SetupLevelItem){
        case 1:  
          TimerTime--;
          if (TimerTime < TimerTimeMin)
              TimerTime = TimerTimeMin;
          ServoTimer = TimerTime;
            break;

        case 6:  
          MinRange--;
          if (MinRange < MinRangeLimit)
              MinRange = MinRangeLimit;
            break;

        case 7:  
          MidRange--;
          if (MidRange < ( MinRange + 100 ))
              MidRange = ( MinRange + 100 );
            break;
      
        case 8:  
          MaxRange--;
          if (MaxRange < ( MidRange + 100 ))
              MaxRange = ( MidRange + 100 );
            break;
        }
      }
      
      }

    ClickTime2 = AktualTime + SecondClickDefault ;
    ClickTime = AktualTime + FirstClickDefault ;
    Zmena++;  
    }

    //MINUS AUTOREPEAT - slower

    if (MinusButtonStatus == LOW & MinusButtonStatusOld == LOW & RunStatus == 1 & AktualTime > ClickTime & AktualTime <= ClickTime2 )
    {
    if (ServoMode == 0)
      {
      val = 5 * ( val/5 ) - 5;

      if (val <= -100)
        val = -100;
      }

    if (ServoMode == 1)
      {
      Step = Step - ValStep;
      if (Step <= MinStep)
        Step = MinStep;
      }

    if (ServoMode == 2)
      {
      Step = Step - ValStep;
      if (Step <= MinStep)
        Step = MinStep;
      }

    if (ServoMode == 3)
      {
      SSSCycleDefault = SSSCycleDefault - SSSCycleStep;
      if (SSSCycleDefault <= SSSCycleMin)
        SSSCycleDefault = SSSCycleMin;
      }

    if (ServoMode == 4 & SetupLevel == 3)
      {


      switch (SetupLevelItem){
        case 1:  
          TimerTime = 5 * ( TimerTime/5 ) - 5;
          if (TimerTime < TimerTimeMin)
            TimerTime = TimerTimeMin;
          ServoTimer = TimerTime;
            break;

        case 6:  
          MinRange = 5 * ( MinRange/5)  - 5;
          if (MinRange < MinRangeLimit)
              MinRange = MinRangeLimit;
            break;

        case 7:  
          MidRange = 5 * ( MidRange/5 ) - 5;
          if (MidRange < ( MinRange + 100 ))
              MidRange = ( MinRange + 100 );
            break;
      
        case 8:  
          MaxRange = 5 * ( MaxRange/5 ) - 5;
          if (MaxRange < ( MidRange + 100 ))
              MaxRange = ( MidRange + 100 );
            break;
        }
      }

      ClickTime = AktualTime + NextClickDefault ;
      Zmena++;
    }
     
    //MINUS AUTOREPEAT - faster
    
    if (MinusButtonStatus == LOW & MinusButtonStatusOld == LOW & RunStatus == 1 & AktualTime > ClickTime2 )
    {
    if (ServoMode == 0 )
      {
      val = 10 * ( val/10 ) - 10;

      if (val <= -100)
        val = -100;
      }

    if (ServoMode == 1)
      {
      Step = Step - ValStep;
      if (Step <= MinStep)
        Step = MinStep;
      }

    if (ServoMode == 2)
      {
      Step = Step - ValStep;
      if (Step <= MinStep)
        Step = MinStep;
      }

    if (ServoMode == 3)
      {
      SSSCycleDefault = SSSCycleDefault - SSSCycleStep;
      if (SSSCycleDefault <= SSSCycleMin)
        SSSCycleDefault = SSSCycleMin;
      }

    if (ServoMode == 4 & SetupLevel == 3)
      {
      Zmena++;

      switch (SetupLevelItem){
        case 1:  
          TimerTime = 10 * ( TimerTime/10 ) - 10;
          if (TimerTime < TimerTimeMin)
            TimerTime = TimerTimeMin;
          ServoTimer = TimerTime;
            break;

        case 6:  
          MinRange = 10 * ( MinRange/10 ) - 10;
          if (MinRange < MinRangeLimit)
              MinRange = MinRangeLimit;
            break;

        case 7:  
          MidRange = 10 * ( MidRange/10 ) - 10;
          if (MidRange < ( MinRange + 100 ))
              MidRange = ( MinRange + 100 );
            break;
      
        case 8:  
          MaxRange = 10 * ( MaxRange/10 ) - 10;
          if (MaxRange < ( MidRange + 100 ))
              MaxRange = ( MidRange + 100 );
            break;
        }
      }

      ClickTime2 = AktualTime + NextClickDefault2 ;
      Zmena++;
   
    }
     MinusButtonStatusOld = MinusButtonStatus;  //END of PLUS button

//********************************************************************************************
//Tlacidlo - PLUS - button
//********************************************************************************************

    PlusButtonStatus = digitalRead(PlusButton);  // read input value

    if (PlusButtonStatus == LOW & PlusButtonStatusOld == HIGH & RunStatus == 0 )
      {
      ServoMode++;
      Zmena++;
      }

    if (PlusButtonStatus == LOW & PlusButtonStatusOld == HIGH & RunStatus == 1 )
    {
    if (ServoMode == 0)
      {
      val++;
      if (val >= +100)
        val = +100;
      }

    if (ServoMode == 1)
      {
      Step = Step + ValStep;
      if (Step >= MaxStep)
        Step = MaxStep;
      }

    if (ServoMode == 2)
      {
      Step = Step + ValStep;
      if (Step >= MaxStep)
        Step = MaxStep;
      }

    if (ServoMode == 3)
      {
      SSSCycleDefault = SSSCycleDefault + SSSCycleStep;
      if (SSSCycleDefault >= SSSCycleMax)
        SSSCycleDefault = SSSCycleMax;
      }

    if (ServoMode == 4)
    {
    if (SetupLevel == 1)
      {
      SetupLevelItem++;
      if (SetupLevelItem > 9)
        SetupLevelItem = 0;
      }

    if (SetupLevel == 2 & ( SetupLevelItem == 1 || ( SetupLevelItem >= 3 & SetupLevelItem <= 8)))
      {
      SetupLevelTwoItem++;
      if (SetupLevelTwoItem > 1)
        SetupLevelTwoItem = 0;
      }

    if (SetupLevel == 2 & ( SetupLevelItem == 2 || SetupLevelItem == 9 )   )
      {
      SetupLevelTwoItem++;
      if (SetupLevelTwoItem > 2)
        SetupLevelTwoItem = 0;
      }


    if (SetupLevel == 3)
      {

      switch (SetupLevelItem){
        case 1:  
          TimerTime++;
          if (TimerTime > TimerTimeMax)
              TimerTime = TimerTimeMax;
          ServoTimer = TimerTime;
            break;

        case 6:  
          MinRange++;
          if (MinRange > ( MidRange - 100 ))
              MinRange = ( MidRange - 100 );
            break;

        case 7:  
          MidRange++;
          if (MidRange > ( MaxRange - 100 ))
              MidRange = ( MaxRange - 100 );
            break;
      
        case 8:  
          MaxRange++;
          if (MaxRange > MaxRangeLimit)
              MaxRange = MaxRangeLimit;
            break;
        }
      }
      }
      ClickTime2 = AktualTime + SecondClickDefault ;
      ClickTime = AktualTime + FirstClickDefault ;
      Zmena++;

    }

    //PLUS AUTOREPEAT - slower
    
    if (PlusButtonStatus == LOW & PlusButtonStatusOld == LOW & RunStatus == 1 & AktualTime > ClickTime & AktualTime <= ClickTime2 )
    {
    if (ServoMode == 0)
      {
      val = 5 * ( val/5 ) + 5;
      if (val >= +100)
        val = +100;
      }

    if (ServoMode == 1 )
      {
      Step = Step + ValStep;
      if (Step >= MaxStep)
        Step = MaxStep;
      }

    if (ServoMode == 2)
      {
      Step = Step + ValStep;
      if (Step >= MaxStep)
        Step = MaxStep;
      }

    if (ServoMode == 3  )
      {
      SSSCycleDefault = SSSCycleDefault + SSSCycleStep;
      if (SSSCycleDefault >= SSSCycleMax)
        SSSCycleDefault = SSSCycleMax;
      }

    if (ServoMode == 4 & SetupLevel == 3 )
      {

      switch (SetupLevelItem){
        case 1:  
          TimerTime = 5 * ( TimerTime/5 ) + 5;
          if (TimerTime > TimerTimeMax)
              TimerTime = TimerTimeMax;
          ServoTimer = TimerTime;
            break;

        case 6:  
          MinRange = 5 * ( MinRange/5 ) + 5;
          if (MinRange > ( MidRange - 100 ))
              MinRange = ( MidRange - 100 );
            break;

        case 7:  
          MidRange = 5 * ( MidRange/5 ) + 5;
          if (MidRange > ( MaxRange - 100 ))
              MidRange = ( MaxRange - 100 );
            break;
      
        case 8:  
          MaxRange = 5 * ( MaxRange/5 ) + 5;
          if (MaxRange > MaxRangeLimit)
              MaxRange = MaxRangeLimit;
            break;
        }
      
      }
      
      ClickTime = AktualTime + NextClickDefault ;
      Zmena++;

     }
     
    //PLUS AUTOREPEAT - slower
    
    if (PlusButtonStatus == LOW & PlusButtonStatusOld == LOW & RunStatus == 1 & AktualTime > ClickTime2 )
    {
    if (ServoMode == 0)
      {
      val = 10 * ( val/10 ) + 10;
      if (val >= +100)
        val = +100;
      }

    if (ServoMode == 1 )
      {
      Step = Step + ValStep;
      if (Step >= MaxStep)
        Step = MaxStep;
      }

    if (ServoMode == 2)
      {
      Step = Step + ValStep;
      if (Step >= MaxStep)
        Step = MaxStep;
      }

    if (ServoMode == 3  )
      {
      SSSCycleDefault = SSSCycleDefault + SSSCycleStep;
      if (SSSCycleDefault >= SSSCycleMax)
        SSSCycleDefault = SSSCycleMax;
      }

    if (ServoMode == 4 & SetupLevel == 3 )
      {

      switch (SetupLevelItem){
        case 1:  
          TimerTime = 10 * ( TimerTime/10 ) + 10;
          if (TimerTime > TimerTimeMax)
              TimerTime = TimerTimeMax;
          ServoTimer = TimerTime;
            break;

        case 6:  
          MinRange = 10 * ( MinRange/10 ) + 10;
          if (MinRange > ( MidRange - 100 ))
              MinRange = ( MidRange - 100 );
            break;

        case 7:  
          MidRange = 10 * ( MidRange/10 ) + 10;
          if (MidRange > ( MaxRange - 100 ))
              MidRange = ( MaxRange - 100 );
            break;
      
        case 8:  
          MaxRange = 10 * ( MaxRange/10 ) + 10;
          if (MaxRange > MaxRangeLimit)
              MaxRange = MaxRangeLimit;
            break;
        }
      
      }
      
      ClickTime2 = AktualTime + NextClickDefault2 ;
      Zmena++;

     }

     PlusButtonStatusOld = PlusButtonStatus;  //END of PLUS button



    if (ServoMode < 0)
        ServoMode = 4;
    if (ServoMode > 4)
        ServoMode = 0;

    SSSval = (float)SSSCycleDefault / 1000.0;

//********************************************************************************************
// vykreslenie  - DISPLAY - drawing
//********************************************************************************************

  if (Zmena > 0)
  {
  u8g.firstPage();

  do {

     u8g.setFont(u8g_font_fur14);

    if (ServoMode == 0)
    u8g.drawStr( 0, 18, "Mode_0");
    if (ServoMode == 1)
    u8g.drawStr( 0, 18, "Mode_1");
    if (ServoMode == 2)
    u8g.drawStr( 0, 18, "Mode_2");
    if (ServoMode == 3)
    u8g.drawStr( 0, 18, "Mode_3");
    if (ServoMode == 4)
    u8g.drawStr( 0, 18, "* SETUP *");


    if (ServoMode == 0)
    u8g.drawStr( 0, 38, "  Manual");
    if (ServoMode == 1)
    u8g.drawStr( 0, 38, "Slow-Slow");
    if (ServoMode == 2)
    u8g.drawStr( 0, 38, "Slow-Quick");
    if (ServoMode == 3)
    u8g.drawStr( 0, 38, "S-S-Step");
    if (ServoMode == 4 & RunStatus == 0)
    u8g.drawStr( 0, 38, "Parameters");

    if ( TimerOn == 1 & ServoMode !=4)
        {
        //ServoTimerDisplay = (ServoTimer);
        temp = (ServoTimer/60);
        u8g.setPrintPos(78, 18);
            u8g.print( temp);

        u8g.drawStr( 101, 18, ":");

        temp = (ServoTimer - (60*temp));
        u8g.setPrintPos(107, 18);
            u8g.print(temp);
        }
      
      
      
      u8g.setFont(u8g_font_fur14);

      if (ServoMode == 4 & RunStatus == 1)
      {
        
      if ( SetupLevel == 1 & SetupLevelItem==0)
      {
        u8g.drawStr( 0, 38, "EXIT");
        u8g.drawStr( 0, 58, "          ");
      }
      if (SetupLevel == 1 & SetupLevelItem==1)
      {
        u8g.drawStr( 0, 38, "Timer");
        u8g.drawStr( 0, 58, "min:sec");
      }
          if (SetupLevel == 2 & SetupLevelItem==1 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "Timer");
            u8g.drawStr( 0, 58, " Set time ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==1 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "Timer");
            u8g.drawStr( 0, 58, " EXIT ");    
           }
              if (SetupLevel == 3 & SetupLevelItem==1 & SetupLevelThreeItem == 0)
                {
                  u8g.drawStr( 0, 38, "Timer");
                    temp = (TimerTime/60);
                    u8g.setPrintPos(28, 58);
                        u8g.print( temp);

                    u8g.drawStr( 51, 58, ":");

                    temp = (TimerTime - (60*temp));
                    u8g.setPrintPos(57, 58);
                        u8g.print(temp);
                }

      if (SetupLevel == 1 & SetupLevelItem==2)
      {
        u8g.drawStr( 0, 38, "Timer");
        u8g.drawStr( 0, 58, " ON/OFF");    
      }
          if (SetupLevel == 2 & SetupLevelItem==2 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "Timer");
            u8g.drawStr( 0, 58, " Timer ON ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==2 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "Timer");
            u8g.drawStr( 0, 58, " Timer OFF ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==2 & SetupLevelTwoItem == 2)
           {
            u8g.drawStr( 0, 38, "Timer");
            u8g.drawStr( 0, 58, " EXIT ");    
           }

      if (SetupLevel == 1 & SetupLevelItem==3)
      {
        u8g.drawStr( 0, 38, "Pulse par.1");
        u8g.drawStr( 0, 58, "1000/2000us");    
      }
          if (SetupLevel == 2 & SetupLevelItem==3 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "Pulse par.1");
            u8g.drawStr( 0, 58, " CHANGE ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==3 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "Pulse par.1");
            u8g.drawStr( 0, 58, " EXIT   ");    
           }
      if (SetupLevel == 1 & SetupLevelItem==4)
      {
        u8g.drawStr( 0, 38, "Pulse par.2");
        u8g.drawStr( 0, 58, "900/2100us");    
      }
          if (SetupLevel == 2 & SetupLevelItem==4 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "Pulse par.2");
            u8g.drawStr( 0, 58, " CHANGE ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==4 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "Pulse par.2");
            u8g.drawStr( 0, 58, " EXIT   ");    
           }
      if (SetupLevel == 1 & SetupLevelItem==5)
      {
        u8g.drawStr( 0, 38, "Pulse par.3");
        u8g.drawStr( 0, 58, "1200/1800us");    
      }
          if (SetupLevel == 2 & SetupLevelItem==5 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "Pulse par.3");
            u8g.drawStr( 0, 58, " CHANGE ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==5 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "Pulse par.3");
            u8g.drawStr( 0, 58, " EXIT   ");    
           }
      if (SetupLevel == 1 & SetupLevelItem==6)
      {
        u8g.drawStr( 0, 38, "User Pulse");
        u8g.drawStr( 0, 58, "Min us");    
      }
          if (SetupLevel == 2 & SetupLevelItem==6 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "User Pulse");
            u8g.drawStr( 0, 58, "Set MinPulse");    
           }
          if (SetupLevel == 2 & SetupLevelItem==6 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "User Pulse");
            u8g.drawStr( 0, 58, " EXIT ");    
           }
              if (SetupLevel == 3 & SetupLevelItem==6 & SetupLevelThreeItem == 0)
                {
                  u8g.drawStr( 0, 38, "Set MinPulse");
                  u8g.drawStr( 100, 58, "us");
                    u8g.setPrintPos(10, 58);
                        u8g.print(MinRange);
                }

      
      if (SetupLevel == 1 & SetupLevelItem==7)
      {
        u8g.drawStr( 0, 38, "User Pulse");
        u8g.drawStr( 0, 58, "Mid us");    
      }
          if (SetupLevel == 2 & SetupLevelItem==7 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "User Pulse");
            u8g.drawStr( 0, 58, "Set MidPulse");    
           }
          if (SetupLevel == 2 & SetupLevelItem==7 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "User Pulse");
            u8g.drawStr( 0, 58, " EXIT ");    
           }
              if (SetupLevel == 3 & SetupLevelItem==7 & SetupLevelThreeItem == 0)
                {
                  u8g.drawStr( 0, 38, "Set MidPulse");
                  u8g.drawStr( 100, 58, "us");
                    u8g.setPrintPos(10, 58);
                        u8g.print(MidRange);
                }

      
      if (SetupLevel == 1 & SetupLevelItem==8)
      {
        u8g.drawStr( 0, 38, "User Pulse");
        u8g.drawStr( 0, 58, "Max us");    
      }
          if (SetupLevel == 2 & SetupLevelItem==8 & SetupLevelTwoItem == 0)
           {
            u8g.drawStr( 0, 38, "User Pulse");
            u8g.drawStr( 0, 58, "Set MaxPulse");    
           }
          if (SetupLevel == 2 & SetupLevelItem==8 & SetupLevelTwoItem == 1)
           {
            u8g.drawStr( 0, 38, "User Pulse");
            u8g.drawStr( 0, 58, " EXIT ");    
           }
              if (SetupLevel == 3 & SetupLevelItem==8 & SetupLevelThreeItem == 0)
                {
                  u8g.drawStr( 0, 38, "Set MaxPulse");
                  u8g.drawStr( 100, 58, "us");
                    u8g.setPrintPos(10, 58);
                        u8g.print(MaxRange);
                }

      
      if (SetupLevel == 1 & SetupLevelItem==9)
      {
//        temp = StoreParam();
        u8g.drawStr( 0, 38, "Store param.");
        u8g.drawStr( 0, 58, "YES/ NO");    
      }
          if (SetupLevel == 2 & SetupLevelItem==9 & SetupLevelTwoItem == 0)
           {
            temp = StoreParam();
            u8g.drawStr( 0, 38, "Store param.");
            u8g.drawStr( 0, 58, " ON ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==9 & SetupLevelTwoItem == 1)
           {
            temp = StoreParam();
            u8g.drawStr( 0, 38, "Store param.");
            u8g.drawStr( 0, 58, " OFF ");    
           }
          if (SetupLevel == 2 & SetupLevelItem==9 & SetupLevelTwoItem == 2)
           {
            temp = StoreParam();
            u8g.drawStr( 0, 38, "Store param.");
            u8g.drawStr( 0, 58, " EXIT ");    
           }

      }
   
    u8g.setFont(u8g_font_fur14);
    u8g.setPrintPos(0, 58);
    if ( RunStatus == 1 & ServoMode == 0 )
        u8g.print(val);
    if ( RunStatus == 1 & ServoMode == 1 )
        u8g.print(Step);
    if ( RunStatus == 1 & ServoMode == 2 )
        u8g.print(Step);
    if ( RunStatus == 1 & ServoMode == 3 )
        u8g.print(SSSval);
    u8g.setFont(u8g_font_fur14);

    if (RunStatus == 0 & val == 0 & ServoMode != 4)
    u8g.drawStr( 0, 58, "**STOP**");

    if (RunStatus == 0 & val != 0)
    u8g.drawStr( 0, 58, "**Wait**");

    if (RunStatus == 1 & ServoMode == 0)
    u8g.drawStr( 55 , 58, "% Run");

    if (RunStatus == 1 & ServoMode == 1)
    u8g.drawStr( 55 , 58, "k Run");

    if (RunStatus == 1 & ServoMode == 2)
    u8g.drawStr( 55 , 58, "k Run");

    if (RunStatus == 1 & ServoMode == 3)
    u8g.drawStr( 55 , 58, "s Run");

    } while( u8g.nextPage() );
  }

//********************************************************************************************
//ovladanie - LED - driving
//********************************************************************************************

  if (Zmena > 0)
  {
    if (ServoMode == 0)
    {
    digitalWrite(MinusLed, HIGH);  // turn LED OFF
    digitalWrite(PlusLed, HIGH);  // turn LED OFF
    Step = StepDefault;
    }
    if (ServoMode == 1)
    {
    digitalWrite(MinusLed, HIGH);  // turn LED OFF
    digitalWrite(PlusLed, LOW);  // turn LED OFF
    }
    if (ServoMode == 2)
    {
    digitalWrite(MinusLed, LOW);  // turn LED OFF
    digitalWrite(PlusLed, HIGH);  // turn LED OFF
    smer = 2;
    }
    if (ServoMode == 3)
    {
    digitalWrite(MinusLed, LOW);  // turn LED OFF
    digitalWrite(PlusLed, LOW);  // turn LED OFF
    }
    if (ServoMode == 4)
    {
    digitalWrite(MinusLed, HIGH);  // turn LED OFF
    digitalWrite(PlusLed, HIGH);  // turn LED OFF
    }

    if (RunStatus == 0 & val == 0)
    digitalWrite(RunLed, HIGH);  // turn LED OFF

    if (RunStatus == 0 & val != 0)
    digitalWrite(RunLed, HIGH);  // turn LED OFF

    if (RunStatus == 1 & ServoMode == 0)
    digitalWrite(RunLed, LOW);  // turn LED OFF

    if (RunStatus == 1 & ServoMode == 1)
    digitalWrite(RunLed, LOW);  // turn LED OFF

    if (RunStatus == 1 & ServoMode == 2)
    digitalWrite(RunLed, LOW);  // turn LED OFF

    if (RunStatus == 1 & ServoMode == 3)
    digitalWrite(RunLed, LOW);  // turn LED OFF

    if (RunStatus == 1 & ServoMode == 4)
    digitalWrite(RunLed, LOW);  // turn LED OFF

    
  Zmena = 0;  
  }
 }

}

//********************************************************************************************
//prerusenie - SERVO driving - interrupt
//********************************************************************************************

ISR(TIMER2_COMPA_vect)
{                                   // zaciatok prerusenia

  citac++;
  if ( citac >= 10)
  {
  citac = 0;
  static boolean state = false;
  state = !state;  // toggle
  digitalWrite (LED, state ? HIGH : LOW);

  if( val <= 0)
    outservo = map(val, -100, 0, MinRange, MidRange);     // scale for negatives
  if( val > 0)
    outservo = map(val, 0, 100, MidRange, MaxRange);     // scale for positives

  digitalWrite(ServoPin, HIGH);
  delayMicroseconds(outservo);    // pulse generating
  digitalWrite(ServoPin, LOW);

  outservo = 2600 - outservo;
  delayMicroseconds( outservo );  // delay for approx. constatnt interrupt processing time, inettupt is always 2600us

//      ********************************
//      *****      ServoMode 0     *****
//      ********************************
//      manual mode, controlled by mail loop

if (ServoMode == 0 & RunStatus == 1)
  {
  
   }
//      *****      koniec ServoMode 0     *****

//      ********************************
//      *****      ServoMode 1     *****
//      ********************************
//      autocycling Slow - Slow, speed controlled by main loop

if (ServoMode == 1 & RunStatus == 1)
  {
  
  if (smer == 1)
    val=val+Step;
  if (smer == 2)
    val=val-Step;

  if (val>= +100)
    {
      val = +100;
      smer = 2;

    }

  if (val<= -100)
    {
      val = -100;
      smer = 1;
    }
   }
//      *****      koniec ServoMode 1     *****

//      ********************************
//      *****      ServoMode 2     *****
//      ********************************
//      autocycling Slow - Step, speed controlled by main loop

if (ServoMode == 2 & RunStatus == 1)
  {
    if (millis() >= ServoModeTwoTimer)
      {
 
        if (smer == 1)
          val=val+Step;
        if (smer == 2)
          val=val-Step;

        if (val>=+100)
          {
            val = +100;
            smer = 2;
          }

        if (val<-100)
          {
            val = 100;
            smer = 2;
            ServoModeTwoTimer = ( millis() + 1000);
          }
      }
   }
//      *****      koniec ServoMode 2     *****

//      ********************************
//      *****      ServoMode 3     *****
//      ********************************
//      autocycling Step - Step - Step, speed controlled by main loop

if (ServoMode == 3 & RunStatus == 1)
  {

  if ( millis() >=SSSCycle)
  {

  SSSCycle = millis() + SSSCycleDefault;
  
  if (smer == 1)
    val=val+100;
  if (smer == 2)
    val=val-100;

  if (val>= +100)
    {
      val = +100;
      smer = 2;

    }

  if (val<= -100)
    {
      val = -100;
      smer = 1;
    }

    }
   }
//      *****      koniec ServoMode 3     *****

//      *****      ukoncovanie pri STOPke     *****

  if ( val < 0 & RunStatus == 0 )
    {
    val++;
    if ( val == 0 )
      Zmena++;
    }

  if ( val > 0 & RunStatus == 0 )
    {
    val--;
    if ( val == 0 )
      Zmena++;
    }

//      *****      koniec ukoncovanie pri STOPke     *****

  }

}                   // koniec prerusenia 

//  *****************************************************
//  ***   EEPROM test, reliable mainly at first start ***
//  *****************************************************

int eepromtest (void)
  {
  eepromok = 0;
  temp = EEPROM.read(0);
  if (temp == 'd')
    {
    temp = EEPROM.read(1);
     if (temp == 'd')
      {
      temp = EEPROM.read(2);
         if (temp == 'a')
         {
         temp = EEPROM.read(120);
           if (temp == 'D')
           {
           temp = EEPROM.read(121);
             if (temp == 'D')
             eepromok = 1;
           }
         }
      }
     }
    return (0);
  }

//  *****************************************************
//  ***   EEPROM init, reliable mainly at first start ***
//  *****************************************************

int eeprominit (void)
  {
  EEPROM.write(0, 'd');
  EEPROM.write(1, 'd');
  EEPROM.write(2, 'a');
  EEPROM.write(3, 'n');
  EEPROM.write(5, 'o');
  EEPROM.write(6, '0');
  EEPROM.write(7, '0');
  EEPROM.write(8, '7');
  EEPROM.write(9, ' ');
  EEPROM.write(10, ' ');

  temp = StoreParameters();
  
  EEPROM.write(120, 'D');
  EEPROM.write(121, 'D');
  eepromok = 1;

  return (0);
  }

//  *****************************************************
//  ***   Print of Pulse parameters                   ***
//  *****************************************************

int PrintParameters (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 15, "PULSE param. ");
    u8g.drawStr( 0, 31, "Min           us");
    u8g.drawStr( 0, 47, "Mid           us");
    u8g.drawStr( 0, 63, "Max          us");

    u8g.setPrintPos(45, 31);
        u8g.print(MinRange);

    u8g.setPrintPos(45, 47);
       u8g.print(MidRange);

    u8g.setPrintPos(45, 63);
        u8g.print(MaxRange);

    } while( u8g.nextPage() );

   delay (3000);
 
   return (0);
  }

//  *****************************************************
//  ***   Print Additional parameters                 ***
//  *****************************************************

int PrintAddParam (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

    if (StoreToEepromOn == 0)
    u8g.drawStr( 0, 15, "EEPROM OFF");
    else
    u8g.drawStr( 0, 15, "EEPROM ON");

    if (TimerOn == 0)
    u8g.drawStr( 0, 31, "TIMER OFF");
    else
    u8g.drawStr( 0, 31, "TIMER ON");

    u8g.drawStr( 0, 47, "Timer TIME:");

    temp = (TimerTime/60);
     u8g.setPrintPos(28, 63);
     u8g.print( temp);

    u8g.drawStr( 51, 63, ":");

    temp = (TimerTime - (60*temp));
      u8g.setPrintPos(57, 63);
      u8g.print(temp);

    } while( u8g.nextPage() );

   delay (3000);
 
   return (0);
  }

//  *****************************************************
//  ***   EEPROM storage of parameters                ***
//  *****************************************************

int StoreParameters (void)
  {

  EEPROM.write(11, lowByte(MinRange));
  EEPROM.write(12, highByte(MinRange));
  EEPROM.write(13, lowByte(MaxRange));
  EEPROM.write(14, highByte(MaxRange));
  EEPROM.write(15, lowByte(MidRange));
  EEPROM.write(16, highByte(MidRange));
  EEPROM.write(17, lowByte(TimerTime));
  EEPROM.write(18, highByte(TimerTime));
  EEPROM.write(19, lowByte(TimerOn));
  EEPROM.write(20, highByte(TimerOn));
  EEPROM.write(21, lowByte(StoreToEepromOn));
  EEPROM.write(22, highByte(StoreToEepromOn));

  return (0);
  }

//  *****************************************************
//  ***   EEPROM storage info                         ***
//  *****************************************************

int StoreInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

//    u8g.drawStr( 0, 15, "            ");
    u8g.drawStr( 0, 31, " Parameters ");
    u8g.drawStr( 0, 47, "  Stored    ");
    u8g.drawStr( 0, 63, " To Eeprom  ");
    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }


//  *****************************************************
//  ***   CANCEL info                                 ***
//  *****************************************************

int CancelInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

//    u8g.drawStr( 0, 15, "            ");
    u8g.drawStr( 0, 31, " No changes ");
    u8g.drawStr( 0, 47, "  Cancelled ");
//    u8g.drawStr( 0, 63, "            ");
    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }

//  *****************************************************
//  ***   TIMER ON  info                              ***
//  *****************************************************

int TimerOnInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

//    u8g.drawStr( 0, 15, "            ");
    u8g.drawStr( 0, 31, " Servo Timer");
    u8g.drawStr( 0, 47, "  ON ");
//    u8g.drawStr( 0, 63, "            ");
    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }

//  *****************************************************
//  ***   TIMER OFF info                              ***
//  *****************************************************

int TimerOffInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

//    u8g.drawStr( 0, 15, " ");
    u8g.drawStr( 0, 31, " Servo Timer");
    u8g.drawStr( 0, 47, "  OFF ");
    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }

//  *****************************************************
//  ***   TIMER TIME info                             ***
//  *****************************************************

int TimerTimeInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 15, "            ");
    u8g.drawStr( 0, 31, " Timer set");
    u8g.drawStr( 0, 47, "   to   ");
                    temp = (ServoTimer/60);
                    u8g.setPrintPos(28, 63);
                        u8g.print( temp);

                    u8g.drawStr( 51, 63, ":");

                    temp = (ServoTimer - (60*temp));
                    u8g.setPrintPos(57, 63);
                        u8g.print(temp);
    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }

//  *****************************************************
//  ***   STORE TO EEPROM ON info                     ***
//  *****************************************************

int StoreToEepromOnInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 31, " Store ON ");

    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }

//  *****************************************************
//  ***   STORE TO EEPROM OFF info                    ***
//  *****************************************************

int StoreToEepromOffInfo (void)
  {

u8g.firstPage();

   do {
 
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 31, " Store OFF  ");

    } while( u8g.nextPage() );

   delay (1000);
 
   return (0);
  }

//  *****************************************************
//  ***   STORE subroutine                            ***
//  *****************************************************

int StoreParam (void)
  {
        u8g.drawStr( 0, 38, "Store param.");
   return (0);
  }

//  *****************************************************
//  ***   MIN PULSE info                              ***
//  *****************************************************

int UserMinInfo (void)
  {
  u8g.firstPage();

   do {
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 31, "Min. Pulse");
    u8g.drawStr( 100, 47, "us");
                    u8g.setPrintPos(10, 47);
                        u8g.print( MinRange);
    } while( u8g.nextPage() );

   delay (1000);
   return (0);
  }

//  *****************************************************
//  ***   MID PULSE info                              ***
//  *****************************************************

int UserMidInfo (void)
  {
  u8g.firstPage();

   do {
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 31, "Mid. Pulse");
    u8g.drawStr( 100, 47, "us");
                    u8g.setPrintPos(10, 47);
                        u8g.print( MidRange);
    } while( u8g.nextPage() );

   delay (1000);
   return (0);
  }

//  *****************************************************
//  ***   MAX PULSE info                              ***
//  *****************************************************

int UserMaxInfo (void)
  {
  u8g.firstPage();

   do {
    u8g.setFont(u8g_font_fur14);

    u8g.drawStr( 0, 31, "Max. Pulse");
    u8g.drawStr( 100, 47, "us");
                    u8g.setPrintPos(10, 47);
                        u8g.print( MaxRange);
    } while( u8g.nextPage() );

   delay (1000);
   return (0);
  }

